@@ -652,7 +652,7 @@ class Entry(BaseClass):
                                        'text/plain; charset=utf-8')
 
             content_length = headers.pop('content-length',
-                                         byte_type(self.body_length))
+                                         self.body_length)
 
             string_list.append('content-type: %s' % content_type)
             if not self.streaming:
@@ -801,7 +801,10 @@ class URIMatcher(object):
 
     def __init__(self, uri, entries, match_querystring=False, priority=0):
         self._match_querystring = match_querystring
-        if type(uri).__name__ == 'SRE_Pattern':
+        # CPython, Jython
+        regex_types = ('SRE_Pattern', 'org.python.modules.sre.PatternObject')
+        is_regex = type(uri).__name__ in regex_types
+        if is_regex:
             self.regex = uri
             result = urlsplit(uri.pattern)
             if result.scheme == 'https':
@@ -882,7 +885,7 @@ class httpretty(HttpBaseClass):
     def match_uriinfo(cls, info):
         items = sorted(
             cls._entries.items(),
-            key=lambda (matcher, _): matcher.priority,
+            key=lambda matcher_entries: matcher_entries[0].priority,
             reverse=True,
         )
         for matcher, value in items:
